OtaManifest

Struct OtaManifest 

pub struct OtaManifest {
    pub build_info_version: String,
    pub board: String,
    pub epoch: u64,
    pub mode: i32,
    pub blob_base_url: String,
    pub images: Vec<Image>,
    pub blobs: Vec<Blob>,
}
The root message for an Over-The-Air (OTA) update manifest.

Fields

build_info_version: String

The version from the build-info of the target build. This field is for informational purposes only and does not change the updater’s behavior.

board: String

The board this OTA is for (e.g., “x64”, “arm64”). The system updater will reject the OTA if this does not match the device’s expected board name from build-info.

epoch: u64

The epoch of this OTA. See RFC-0071 for details.

mode: i32

The update mode, indicating if this is a normal update or a forced recovery.

blob_base_url: String

The base URL prefix of the blobs, including the delivery blob type. The final URL for each blob will be “{blob_base_url}/{fuchsia_merkle_root}”. Relative URLs are supported, and will be resolved relative to the URL of the OTA manifest.

images: Vec<Image>

The partition images that should be written during the update.

blobs: Vec<Blob>

Additional blobs that should be written to blob storage.

Implementations

Source

impl OtaManifest

pub fn mode(&self) -> UpdateMode

Returns the enum value of mode, or the default if the field is set to an invalid enum value.

pub fn set_mode(&mut self, value: UpdateMode)

Sets mode to the provided enum value.