pub struct Signatures {
pub manifest_signature: Vec<u8>,
pub manifest_public_key: Vec<u8>,
pub manifest_key_signature: Vec<u8>,
}Expand description
Signatures containing the delegation chain: Root Key -> Manifest Key -> Manifest.
Fields
manifest_signature: Vec<u8>The Ed25519 signature of the manifest, signed by the manifest key.
manifest_public_key: Vec<u8>The public key of the manifest signing key.
manifest_key_signature: Vec<u8>The Ed25519 signature of the manifest public key, signed by the root key.